' Create Temp File

' This function creates a temporary file with a unique filename, closes
' the file, and returns the name of the file (including the path) as the
' return value of the function.  If an error occurred, a null string is
' returned, and the DOS error code is returned in the ECode% parameter.

' Path$ is the path in which the temp file is to be created; it must be
'   terminated with a \
' ECode% is the DOS error code
'   0 = Ok
'   3 = path not found
'   4 = too many open files (increase the FILES= line in CONFIG.SYS)
'   5 = access denied (user does not have create rights in the specified path)


FUNCTION CreateTemp$(Path$, ECode%) LOCAL PUBLIC

  LOCAL TempPath$, Flags%, FileHan%

  TempPath$ = Path$ + STRING$(13, CHR$(0)) ' append 13 nulls to the path name

  REG 1, &H5A00              ' set AH to 5Ah
  REG 3, 0                   ' set CX to 0 (file attribute for temp file)
  REG 8, STRSEG(TempPath$)   ' set DS to segment of path string
  REG 4, STRPTR(TempPath$)   ' set DX to offset of path string
  CALL INTERRUPT &H21        ' call DOS services
  Flags% = REG(0)            ' assign value of the flags value to a temporary register
  IF BIT(Flags%, 0) THEN     ' the carry flag is set, so an error occurred
    ECode% = REG(1)
    CreateTemp$ = ""
  ELSE                       ' file creation was successful
    FileHan% = REG(1)
    ' close the temporary file (so the calling program can open it with a PB file handle)
    REG 1, &H3E00            ' set AH to 3Eh
    REG 2, FileHan%          ' set BX to file handle
    CALL INTERRUPT &H21      ' call DOS services
    ECode% = 0
    CreateTemp$ = RTRIM$(TempPath$, CHR$(0))
  END IF

END FUNCTION
